<?php
/**
 *
 * Show Snow extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2018 Picaron
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace Picaron\ShowSnow\event;

/**
 * Event listener
 */
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{    
    /** @var \phpbb\config\config */
    protected $config;
    
    /** @var \phpbb\user */
    protected $user;

    /** @var \phpbb\template\template */
    protected $template;

    /** @var \phpbb\db\driver\driver_interface */
    protected $db;

    /** @var \phpbb\auth\auth */
    protected $auth;

    /** @var \phpbb\request\request */
    protected $request;

    /** @var string */
    protected $phpbb_root_path;

    /** @var string */
    protected $phpEx;

    /**
    * Constructor
    *
    * @param \phpbb\config\config               $config    
    * @param \phpbb\user                        $user
    * @param \phpbb\template\template           $template
    * @param \phpbb\db\driver\driver_interface  $db
    * @param \phpbb\auth\auth                   $auth
    * @param \phpbb\request\request             $request
    * @param string                             $phpbb_root_path
    * @param string                             $phpEx
    *
    */
    public function __construct(\phpbb\config\config $config, \phpbb\user $user, \phpbb\template\template $template, \phpbb\db\driver\driver_interface $db, \phpbb\auth\auth $auth, \phpbb\request\request $request, $phpbb_root_path, $phpEx)
    {
        $this->config               = $config;        
        $this->user                 = $user;
        $this->template             = $template;
        $this->db                   = $db;
        $this->auth                 = $auth;
        $this->request              = $request;
        $this->phpbb_root_path      = $phpbb_root_path;
        $this->phpEx                = $phpEx;
    }

    /**
     * Assign functions defined in this class to event listeners in the core
     *
     * @return array
     * @static
     * @access public
     */
    static public function getSubscribedEvents()
    {
        return array(
            'core.page_header' => 'page_header',
        );
    }

    /**
     * Set Show Snow template data - Execute code and/or overwrite page_header()
     *
     * @return null
     * @access public
     */
    public function page_header()
    {
        global $config;
        
        $snow = $this->request->variable('snow', 'NO');

        if ($snow == 'click')
        {
            // Check Cookie
            if ($this->request->variable($config['cookie_name'] . '_ShowSnow', '', true, \phpbb\request\request_interface::COOKIE) == 'NO')
            {
                // Cookie OFF
                $this->user->set_cookie('ShowSnow', 'YES', time() - 2592000);
                $visible = true;
            } else {
                // Cookie ON
                $this->user->set_cookie('ShowSnow', 'NO', time() + 2592000);
                $visible = false;
            }
            redirect('./ucp.php?i=-Picaron-ShowSnow-ucp-ucp_showsnow_module&mode=showsnow');
        } else {
            $visible = ($this->request->variable($config['cookie_name'] . '_ShowSnow', '', true, \phpbb\request\request_interface::COOKIE) == 'NO') ? false : true;            
        }

        $this->user->add_lang_ext('Picaron/ShowSnow', 'show_snow');
        $this->template->assign_vars(array(
            'S_SHOW_SNOW'           => $this->user->lang['SNOW'],
            'S_SHOW_SNOW_TITLE'     => $visible ? $this->user->lang['SNOW_TITLE_ON'] : $this->user->lang['SNOW_TITLE_OFF'],
            'S_SHOW_SNOW_STATE'     => $visible ? $this->user->lang['SNOW_ON'] : $this->user->lang['SNOW_OFF'],
            'S_SHOW_SNOW_URL'       => append_sid("{$this->phpbb_root_path}index.{$this->phpEx}?snow=click"),
            'S_SHOW_SNOW_ON'        => $visible,
        ));
    }
}
?>